.. _ovn_ovn:

===============
OVN information
===============

The original OVN project announcement can be found here:

* https://networkheresy.com/2015/01/13/ovn-bringing-native-virtual-networking-to-ovs/

The OVN architecture is described here:

* http://www.ovn.org/support/dist-docs/ovn-architecture.7.html

Here are two tutorials that help with learning different aspects of OVN:

* https://blog.spinhirne.com/posts/an-introduction-to-ovn/a-primer-on-ovn/
* https://docs.ovn.org/en/stable/tutorials/ovn-sandbox.html

There is also an in depth tutorial on using OVN with OpenStack:

* https://docs.ovn.org/en/stable/tutorials/ovn-openstack.html

OVN DB schemas and other man pages:

* http://www.ovn.org/support/dist-docs/ovn-nb.5.html
* http://www.ovn.org/support/dist-docs/ovn-sb.5.html
* http://www.ovn.org/support/dist-docs/ovn-nbctl.8.html
* http://www.ovn.org/support/dist-docs/ovn-sbctl.8.html
* http://www.ovn.org/support/dist-docs/ovn-northd.8.html
* http://www.ovn.org/support/dist-docs/ovn-controller.8.html
* http://www.ovn.org/support/dist-docs/ovn-controller-vtep.8.html

or find a full list of OVS and OVN man pages here:

* http://docs.ovn.org/en/latest/ref/

The openvswitch web page includes a list of presentations, some of which are
about OVN:

* http://openvswitch.org/support/

Here are some direct links to past OVN presentations:

* `OVN talk at OpenStack Summit in Boston, Spring 2017
  <https://www.youtube.com/watch?v=sgc7myiX6ts>`_
* `OVN talk at OpenStack Summit in Barcelona, Fall 2016
  <https://www.youtube.com/watch?v=q3cJ6ezPnCU>`_
* `OVN talk at OpenStack Summit in Austin, Spring 2016
  <https://www.youtube.com/watch?v=okralc7LrZo>`_
* OVN Project Update at the OpenStack Summit in Tokyo, Fall 2015 -
  `Slides <http://openvswitch.org/support/slides/OVN_Tokyo.pdf>`__ -
  `Video <https://www.youtube.com/watch?v=3IrG2xghJjs>`__
* OVN at OpenStack Summit in Vancouver, Sping 2015 -
  `Slides <http://openvswitch.org/support/slides/OVN-Vancouver.pdf>`__ -
  `Video <https://www.youtube.com/watch?v=kEzXTq2fPDg>`__
* `OVS Conference 2015 <https://www.youtube.com/watch?v=JLGZOYi_Cqc>`_

These blog resources may also help with testing and understanding OVN:

* http://networkop.co.uk/blog/2016/11/27/ovn-part1/
* http://networkop.co.uk/blog/2016/12/10/ovn-part2/
* https://blog.russellbryant.net/2016/12/19/comparing-openstack-neutron-ml2ovs-and-ovn-control-plane/
* https://blog.russellbryant.net/2016/11/11/ovn-logical-flows-and-ovn-trace/
* https://blog.russellbryant.net/2016/09/29/ovs-2-6-and-the-first-release-of-ovn/
* http://galsagie.github.io/2015/11/23/ovn-l3-deepdive/
* http://blog.russellbryant.net/2015/10/22/openstack-security-groups-using-ovn-acls/
* http://galsagie.github.io/sdn/openstack/ovs/2015/05/30/ovn-deep-dive/
* http://blog.russellbryant.net/2015/05/14/an-ez-bake-ovn-for-openstack/
* http://galsagie.github.io/sdn/openstack/ovs/2015/04/26/ovn-containers/
* http://blog.russellbryant.net/2015/04/21/ovn-and-openstack-status-2015-04-21/
* http://blog.russellbryant.net/2015/04/08/ovn-and-openstack-integration-development-update/
* http://dani.foroselectronica.es/category/openstack/ovn/
